@@ -5,31 +5,49 @@ form definitions (which fields are available, order, autofocus, ...)
 
 from django import forms
 
-from .models import Host, Domain, ServiceUpdaterHostConfig
+from .models import Host, RelatedHost, Domain, ServiceUpdaterHostConfig
 
 
 class CreateHostForm(forms.ModelForm):
     class Meta(object):
         model = Host
-        fields = ['subdomain', 'domain', 'comment']
+        fields = ['name', 'domain', 'comment']
         widgets = {
-            'subdomain': forms.widgets.TextInput(attrs=dict(autofocus=None)),
+            'name': forms.widgets.TextInput(attrs=dict(autofocus=None)),
         }
 
 
 class EditHostForm(forms.ModelForm):
     class Meta(object):
         model = Host
-        fields = ['comment', 'available', 'abuse']
+        fields = ['comment', 'available', 'abuse', 'netmask_ipv4', 'netmask_ipv6']
+
+    netmask_ipv4 = forms.IntegerField(min_value=0, max_value=32)
+    netmask_ipv6 = forms.IntegerField(min_value=0, max_value=64)
+
+
+class CreateRelatedHostForm(forms.ModelForm):
+    class Meta(object):
+        model = RelatedHost
+        fields = ['name', 'comment', 'available', 'interface_id_ipv4', 'interface_id_ipv6']
+        widgets = {
+            'name': forms.widgets.TextInput(attrs=dict(autofocus=None)),
+        }
+
+
+class EditRelatedHostForm(forms.ModelForm):
+    class Meta(object):
+        model = RelatedHost
+        fields = ['name', 'comment', 'available', 'interface_id_ipv4', 'interface_id_ipv6']
 
 
 class CreateDomainForm(forms.ModelForm):
     class Meta(object):
         model = Domain
-        fields = ['domain', 'nameserver_ip', 'nameserver_update_algorithm',
+        fields = ['name', 'nameserver_ip', 'nameserver_update_algorithm',
                   'public', 'available', 'comment']
         widgets = {
-            'domain': forms.widgets.TextInput(attrs=dict(autofocus=None)),
+            'name': forms.widgets.TextInput(attrs=dict(autofocus=None)),
         }
 
 
