@@ -8,7 +8,8 @@ from django.views.generic import TemplateView
 from .views import (
     HomeView, OverviewView, HostView, AddHostView, DeleteHostView, AboutView, GenerateSecretView, GenerateNSSecretView,
     RobotsTxtView, DomainView, AddDomainView, DeleteDomainView, StatusView, JsUpdateView,
-    UpdaterHostConfigOverviewView, UpdaterHostConfigView, DeleteUpdaterHostConfigView, CustomTemplateView)
+    UpdaterHostConfigOverviewView, UpdaterHostConfigView, DeleteUpdaterHostConfigView,
+    RelatedHostOverviewView, RelatedHostView, AddRelatedHostView, DeleteRelatedHostView, CustomTemplateView)
 from ..api.views import (
     myip_view, DetectIpView, AjaxGetIps, NicUpdateView, AuthorizedNicUpdateView,
     NicDeleteView, AuthorizedNicDeleteView)
@@ -22,13 +23,18 @@ urlpatterns = patterns(
     url(r'^custom/(?P<template>[\w.]+)$', CustomTemplateView.as_view(), name="custom"),
     url(r'^update$', JsUpdateView.as_view(), name='update'),
     url(r'^overview/$', OverviewView.as_view(), name='overview'),
-    url(r'^host/(?P<pk>\d+)/$', HostView.as_view(), name='host_view'),
-    url(r'^domain/(?P<pk>\d+)/$', DomainView.as_view(), name='domain_view'),
     url(r'^status/$', StatusView.as_view(), name='status'),
     url(r'^generate_secret/(?P<pk>\d+)/$', GenerateSecretView.as_view(), name='generate_secret_view'),
     url(r'^generate_ns_secret/(?P<pk>\d+)/$', GenerateNSSecretView.as_view(), name='generate_ns_secret_view'),
+    url(r'^host/(?P<pk>\d+)/$', HostView.as_view(), name='host_view'),
     url(r'^host/add/$', AddHostView.as_view(), name='add_host'),
     url(r'^host/(?P<pk>\d+)/delete/$', DeleteHostView.as_view(), name='delete_host'),
+    url(r'^host/(?P<mpk>\d+)/related/$', RelatedHostOverviewView.as_view(), name='related_host_overview'),
+    url(r'^host/(?P<mpk>\d+)/related/(?P<pk>\d+)/$', RelatedHostView.as_view(), name='related_host_view'),
+    url(r'^host/(?P<mpk>\d+)/related/add/$', AddRelatedHostView.as_view(), name='add_related_host'),
+    url(r'^host/(?P<mpk>\d+)/related/(?P<pk>\d+)/delete/$', DeleteRelatedHostView.as_view(),
+        name='delete_related_host'),
+    url(r'^domain/(?P<pk>\d+)/$', DomainView.as_view(), name='domain_view'),
     url(r'^domain/add/$', AddDomainView.as_view(), name='add_domain'),
     url(r'^domain/(?P<pk>\d+)/delete/$', DeleteDomainView.as_view(), name='delete_domain'),
     url(r'^updater_hostconfig_overview/(?P<pk>\d+)/$', UpdaterHostConfigOverviewView.as_view(),
